==> terasoluna-batch4j-projects_2.0.2.0.zip: terasoluna-filedao/sources/jp/terasoluna/fw/file/dao/standard/DateColumnParser.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.file.dao.standard;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * t̂߂̃Jp[T[NXB
 * 
 * <p>
 * w肳ꂽp[XADate^ɕϊB
 * ϊʂt@CsIuWFNgDate^̑ɒli[B
 * </p>
 * 
 */
public class DateColumnParser implements ColumnParser {

     /**
      * ttH[}bgi[}bv
      */
     private Map<String, DateFormatLocal> map =
         new ConcurrentHashMap<String, DateFormatLocal>();

    /**
     * w肳ꂽp[XADate^ɕϊBϊʂt@CsIuWFNgɊi[B
     * 
     * @param column J̕
     * @param t t@CsIuWFNg
     * @param method J̕t@CsIuWFNgɊi[郁\bh
     * @param columnFormat p[Xۂ̃tH[}bg
     * @throws IllegalArgumentException tH[}bg񂪃tH[}bgƂĕsłƂ
     * @throws IllegalAccessException t@CsIuWFNgւ̐ݒ肪sƂ
     * @throws InvocationTargetException t@CsIuWFNg̃\bhOX[Ƃ
     * @throws ParseException p[XsƂ
     */
    public void parse(String column, Object t, Method method,
            String columnFormat) throws IllegalArgumentException,
            IllegalAccessException, InvocationTargetException, ParseException {
        String pattern = columnFormat;
        if (pattern == null || "".equals(pattern)) {
            pattern = "yyyyMMdd";
        }
        DateFormatLocal dflocal = null;
        dflocal = map.get(pattern);
        if (dflocal == null) {
            dflocal = new DateFormatLocal(pattern);
            map.put(pattern, dflocal);
        }
        DateFormat df = dflocal.get();
        method.invoke(t, df.parse(column));
    }
}

==> terasoluna-batch4j-projects_2.0.3.1.zip: terasoluna-filedao/sources/jp/terasoluna/fw/file/dao/standard/DateColumnParser.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.file.dao.standard;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * t̂߂̃Jp[T[NXB
 * <p>
 * w肳ꂽp[XADate^ɕϊB ϊʂt@CsIuWFNgDate^̑ɒli[B
 * </p>
 */
public class DateColumnParser implements ColumnParser {

    /**
     * ttH[}bgi[}bv
     */
    private Map<String, DateFormatLocal> map = new ConcurrentHashMap<String, DateFormatLocal>();

    /**
     * w肳ꂽp[XADate^ɕϊBϊʂt@CsIuWFNgɊi[B
     * @param column J̕
     * @param t t@CsIuWFNg
     * @param method J̕t@CsIuWFNgɊi[郁\bh
     * @param columnFormat p[Xۂ̃tH[}bg
     * @throws IllegalArgumentException tH[}bg񂪃tH[}bgƂĕsłƂ
     * @throws IllegalAccessException t@CsIuWFNgւ̐ݒ肪sƂ
     * @throws InvocationTargetException t@CsIuWFNg̃\bhOX[Ƃ
     * @throws ParseException p[XsƂ
     */
    public void parse(String column, Object t, Method method,
            String columnFormat) throws IllegalArgumentException,
                                IllegalAccessException,
                                InvocationTargetException, ParseException {
        String pattern = columnFormat;
        if (pattern == null || "".equals(pattern)) {
            pattern = "yyyyMMdd";
        }
        DateFormatLocal dflocal = null;
        dflocal = map.get(pattern);
        if (dflocal == null) {
            dflocal = new DateFormatLocal(pattern);
            map.put(pattern, dflocal);
        }
        DateFormat df = dflocal.get();
        method.invoke(t, df.parse(column));
    }
}
